@@ -7,8 +7,8 @@ detect_input_type <- function(data,
                               treatment="treatment",
                               outcome="outcome") {
   # if(class == "baggr_data")
-  if(!("data.frame" %in% class(data)))
-    stop("Can't detect input type because it's not data.frame")
+  if(!inherits(data, "data.frame"))
+    stop("Can't detect input type because it's not a data.frame")
 
   # Summary data -----
   if("tau" %in% names(data) && "se" %in% names(data)){
@@ -18,12 +18,13 @@ detect_input_type <- function(data,
       return("pool_noctrl_narrow")
   }
 
+  if(check_columns_binary(data, stop = FALSE))
+    return("pool_binary")
+
   if(!any(is.na(match(c("tau", "mu", "se.mu", "se.tau"),
                       names(data)))))
     return("pool_wide")
 
-  if(check_columns_binary(data, stop = FALSE))
-    return("pool_binary")
 
   # Individual-level data -----
   if(!is.null(data[[group]])){
